searchNodes=[{"doc":"Data migrations are used to modify the data in your database over time.This module provides many helpers for migrating the database, allowing developers to use Elixir to alter their storage in a way that is database independent.Here is an example:defmodule ExampleApp.Repo.DataMigrations.AddJohn do use EctoImmigrant.Migration alias ExampleApp.Repo alias ExampleApp.Person def up do Repo.insert(%Person{id: 123, first_name: &quot;John&quot;, last_name: &quot;Doe&quot;, age: 78}) end def down do Repo.delete(%Person{id: 123, first_name: &quot;John&quot;, last_name: &quot;Doe&quot;, age: 78}) end endNote data migrations have an up/0 and down/0, which is used to update your data and reverts the updated data, respectively.EctoImmigrant provides some mix tasks to help developers work with migrations:mix ecto_immigrant.gen.migration # Generates a new data migration for the repomix ecto_immigrant.migrate # Runs the repository data migrationsmix ecto_immigrant.rollback # Reverts applied data migrations from the repositorymix ecto_immigrant.migrations # Displays the repository data migration statusRun the mix help COMMAND for more information.TransactionsBy default, Ecto_Immigrant runs all migrations inside a transaction. That's not always ideal: for example, PostgreSQL allows to create/drop indexes concurrently but only outside of any transaction (see the PostgreSQL docs).Data migrations can be forced to run outside a transaction by setting the @disable_ddl_transaction module attribute to true:defmodule ExampleApp.Repo.DataMigrations.AddJohn do use EctoImmigrant.Migration @disable_ddl_transaction true alias ExampleApp.Repo alias ExampleApp.Person def up do Repo.insert(%Person{id: 123, first_name: &quot;John&quot;, last_name: &quot;Doe&quot;, age: 78}) end def down do Repo.delete(%Person{id: 123, first_name: &quot;John&quot;, last_name: &quot;Doe&quot;, age: 78}) end endSince running migrations outside a transaction can be dangerous, consider performing very few operations in such migrations.","ref":"EctoImmigrant.Migration.html","title":"EctoImmigrant.Migration","type":"module"},{"doc":"This module provides the data migration API.Exampledefmodule MyApp.MigrationExample do use EctoImmigrant.Migration alias MyApp.Repo alias MyApp.Person def up do Repo.insert(%Person{id: 123, first_name: &quot;John&quot;, last_name: &quot;Doe&quot;, age: 78}) end def down do Repo.delete(%Person{id: 123, first_name: &quot;John&quot;, last_name: &quot;Doe&quot;, age: 78}) end end EctoImmigrant.Migrator.up(Repo, 20080906120000, MyApp.MigrationExample) EctoImmigrant.Migrator.down(Repo, 20080906120000, MyApp.MigrationExample)","ref":"EctoImmigrant.Migrator.html","title":"EctoImmigrant.Migrator","type":"module"},{"doc":"Reverts an applied data migration on the given repository.","ref":"EctoImmigrant.Migrator.html#down/4","title":"EctoImmigrant.Migrator.down/4","type":"function"},{"doc":"Gets all migrated versions.This function ensures the data migration table exists if no table has been defined yet.Options:log - the level to use for logging. Defaults to :info. Can be any of Logger.level/0 values or false.:prefix - the prefix to run the migrations on","ref":"EctoImmigrant.Migrator.html#migrated_versions/2","title":"EctoImmigrant.Migrator.migrated_versions/2","type":"function"},{"doc":"Returns an array of tuples as the migration status of the given repo, without actually running any migrations.","ref":"EctoImmigrant.Migrator.html#migrations/2","title":"EctoImmigrant.Migrator.migrations/2","type":"function"},{"doc":"Apply migrations to a repository with a given strategy.The second argument identifies where the migrations are sourced from. A file path may be passed, in which case the migrations will be loaded from this during the migration process. The other option is to pass a list of tuples that identify the version number and migration modules to be run, for example:EctoImmigrant.Migrator.run(Repo, [{0, MyApp.Migration1}, {1, MyApp.Migration2}, ...], :up, opts)A strategy must be given as an option.Options:all - runs all available if true:log - the level to use for logging. Defaults to :info. Can be any of Logger.level/0 values or false.:prefix - the prefix to run the migrations on","ref":"EctoImmigrant.Migrator.html#run/4","title":"EctoImmigrant.Migrator.run/4","type":"function"},{"doc":"Runs an up data migration on the given repository.Options:log - the level to use for logging. Defaults to :info. Can be any of Logger.level/0 values or false.:prefix - the prefix to run the migrations on","ref":"EctoImmigrant.Migrator.html#up/4","title":"EctoImmigrant.Migrator.up/4","type":"function"},{"doc":"Generates a data migration.The repository must be set under :ecto_repos in the current app configuration.Examplesmix ecto_immigrant.gen.migration add_admin_to_users_tableThe generated migration filename will be prefixed with the current timestamp in UTC which is used for versioning and ordering.By default, the migration will be generated to the &quot;priv/YOUR_REPO/data_migrations&quot; directory of the current application but it can be configured to be any subdirectory of priv by specifying the :priv key under the repository configuration.This generator will automatically open the generated file if you have ECTO_EDITOR set in your environment variable.Command line options-r, --repo - the repo to generate migration for","ref":"Mix.Tasks.EctoImmigrant.Gen.Migration.html","title":"Mix.Tasks.EctoImmigrant.Gen.Migration","type":"task"},{"doc":"Runs the pending data migrations for the given repository.Data migrations are expected at &quot;priv/YOUR_REPO/data_migrations&quot; directory of the current application, where &quot;YOUR_REPO&quot; is the last segment in your repository name. For example, the repository MyApp.Repo will use &quot;priv/repo/data_migrations&quot;. The repository Whatever.MyRepo will use &quot;priv/my_repo/data_migrations&quot;.This task runs all pending data migrations by default.If a repository has not yet been started, one will be started outside your application supervision tree and shutdown afterwards.Examplesmix ecto_immigrant.migrate","ref":"Mix.Tasks.EctoImmigrant.Migrate.html","title":"Mix.Tasks.EctoImmigrant.Migrate","type":"task"},{"doc":"Displays the up / down data migration status for the given repository.The repository must be set under :ecto_repos in the current app configuration or given via the -r option.By default, data migrations are expected at &quot;priv/YOUR_REPO/data_migrations&quot; directory of the current application but it can be configured by specifying the :priv key under the repository configuration.If the repository has not been started yet, one will be started outside our application supervision tree and shutdown afterwards.Examplesmix ecto_immigrant.migrations mix ecto_immigrant.migrations -r Custom.RepoCommand line options-r, --repo - the repo to obtain the status for","ref":"Mix.Tasks.EctoImmigrant.Migrations.html","title":"Mix.Tasks.EctoImmigrant.Migrations","type":"task"},{"doc":"Reverts applied data migrations for the given repository.Data migrations are expected at &quot;priv/YOUR_REPO/data_migrations&quot; directory of the current application, where &quot;YOUR_REPO&quot; is the last segment in your repository name. For example, the repository MyApp.Repo will use &quot;priv/repo/data_migrations&quot;. The repository Whatever.MyRepo will use &quot;priv/my_repo/data_migrations&quot;.This task rolls back the last applied data migrations by default.If a repository has not yet been started, one will be started outside your application supervision tree and shutdown afterwards.Examplesmix ecto_immigrant.rollback mix ecto_immigrant.rollback -r Custom.Repo mix ecto_immigrant.rollback -n 3 mix ecto_immigrant.rollback --step 3 mix ecto_immigrant.rollback --to 20080906120000Command line options-r, --repo - the repo to rollback--all - revert all applied migrations--step, -n - revert n number of applied migrations--to - revert all migrations down to and including version--quiet - do not log migration commands--prefix - the prefix to run migrations on--log-sql - log the raw sql migrations are running","ref":"Mix.Tasks.EctoImmigrant.Rollback.html","title":"Mix.Tasks.EctoImmigrant.Rollback","type":"task"},{"doc":"","ref":"EctoImmigrant.MigrationError.html","title":"EctoImmigrant.MigrationError","type":"exception"}]